@@ -1,11 +1,8 @@
 import functools
+import json
 import operator
 import os
 import re
-try:
-    import simplejson as json
-except ImportError:
-    import json
 
 from flask import Blueprint
 from flask import Response
@@ -78,7 +75,7 @@ class AdminFilterModelConverter(FilterModelConverter):
 class Action(object):
     def __init__(self, name=None, description=None):
         self.name = name or (type(self).__name__.replace('Action', ''))
-        self.description = description or re.sub('[\-_]', ' ', self.name).title()
+        self.description = description or re.sub(r'[\-_]', ' ', self.name).title()
 
     def callback(self, id_list):
         """
@@ -261,6 +258,7 @@ class ModelAdmin(object):
         pq = PaginatedQuery(query, self.paginate_by)
 
         return render_template(self.templates['index'],
+            admin=self.admin,
             model_admin=self,
             query=pq,
             ordering=ordering,
@@ -299,6 +297,7 @@ class ModelAdmin(object):
             form = Form()
 
         return render_template(self.templates['add'],
+            admin=self.admin,
             model_admin=self,
             form=form,
             instance=instance,
@@ -323,6 +322,7 @@ class ModelAdmin(object):
             form = Form(obj=instance)
 
         return render_template(self.templates['edit'],
+            admin=self.admin,
             model_admin=self,
             instance=instance,
             form=form,
@@ -365,6 +365,7 @@ class ModelAdmin(object):
             return self._index_redirect()
 
         return render_template(self.templates['delete'], **dict(
+            admin=self.admin,
             model_admin=self,
             query=query,
             collected=collected,
@@ -405,6 +406,7 @@ class ModelAdmin(object):
             return export.json_response('export-%s.json' % self.get_admin_name())
 
         return render_template(self.templates['export'],
+            admin=self.admin,
             model_admin=self,
             model=query.model,
             query=query,
@@ -484,87 +486,8 @@ class AdminPanel(object):
         return render_template(self.get_template_name(), panel=self, **self.get_context())
 
 
-class AdminTemplateHelper(object):
-    def __init__(self, admin):
-        self.admin = admin
-        self.app = self.admin.app
-
-    def get_model_field(self, model, field):
-        try:
-            attr = getattr(model, field)
-        except AttributeError:
-            model_admin = self.admin[type(model)]
-            try:
-                attr = getattr(model_admin, field)
-            except AttributeError:
-                raise AttributeError('Could not find attribute or method '
-                                     'named "%s".' % field)
-            else:
-                return attr(model)
-        else:
-            if callable(attr):
-                attr = attr()
-            return attr
-
-    def get_form_field(self, form, field_name):
-        return getattr(form, field_name)
-
-    def fix_underscores(self, s):
-        return s.replace('_', ' ').title()
-
-    def update_querystring(self, querystring, key, val):
-        if not querystring:
-            return '%s=%s' % (key, val)
-        else:
-            querystring = re.sub('%s(?:[^&]+)?&?' % key, '', querystring.decode('utf8')).rstrip('&')
-            return ('%s&%s=%s' % (querystring, key, val)).lstrip('&')
-
-    def get_verbose_name(self, model, column_name):
-        try:
-            field = model._meta.fields[column_name]
-        except KeyError:
-            return self.fix_underscores(column_name)
-        else:
-            return field.verbose_name or self.fix_underscores(field.name)
-
-    def get_model_admins(self):
-        return {'model_admins': self.admin.get_model_admins(), 'branding': self.admin.branding}
-
-    def get_admin_url(self, obj):
-        model_admin = self.admin.get_admin_for(type(obj))
-        if model_admin:
-            return url_for(model_admin.get_url_name('edit'), pk=obj._pk)
-
-    def get_model_name(self, model_class):
-        model_admin = self.admin.get_admin_for(model_class)
-        if model_admin:
-            return model_admin.get_display_name()
-        return model_class.__name__
-
-    def apply_prefix(self, field_name, prefix_accum, field_prefix, rel_prefix='fr_', rel_sep='-'):
-        accum = []
-        for prefix in prefix_accum:
-            accum.append('%s%s' % (rel_prefix, prefix))
-        accum.append('%s%s' % (field_prefix, field_name))
-        return rel_sep.join(accum)
-
-    def prepare_environment(self):
-        self.app.template_context_processors[None].append(self.get_model_admins)
-
-        self.app.jinja_env.globals['get_model_field'] = self.get_model_field
-        self.app.jinja_env.globals['get_form_field'] = self.get_form_field
-        self.app.jinja_env.globals['get_verbose_name'] = self.get_verbose_name
-        self.app.jinja_env.filters['fix_underscores'] = self.fix_underscores
-        self.app.jinja_env.globals['update_querystring'] = self.update_querystring
-        self.app.jinja_env.globals['get_admin_url'] = self.get_admin_url
-        self.app.jinja_env.globals['get_model_name'] = self.get_model_name
-
-        self.app.jinja_env.filters['apply_prefix'] = self.apply_prefix
-
-
 class Admin(object):
-    def __init__(self, app, auth, template_helper=AdminTemplateHelper,
-                 prefix='/admin', name='admin', branding='flask-peewee'):
+    def __init__(self, app, auth, prefix='/admin', name='admin', branding='flask-peewee'):
         self.app = app
         self.auth = auth
 
@@ -574,12 +497,13 @@ class Admin(object):
 
         self.blueprint = self.get_blueprint(name)
         self.url_prefix = prefix
-
-        self.template_helper = template_helper(self)
-        self.template_helper.prepare_environment()
-
         self.branding = branding
 
+        self.prepare_template_environment()
+
+    def get_url_name(self, name):
+        return '%s.%s' % (self.blueprint.name, name)
+
     def auth_required(self, func):
         @functools.wraps(func)
         def inner(*args, **kwargs):
@@ -636,9 +560,9 @@ class Admin(object):
 
     def index(self):
         return render_template('admin/index.html',
-            model_admins=self.get_model_admins(),
-            panels=self.get_panels(),
-        )
+                               admin=self,
+                               model_admins=self.get_model_admins(),
+                               panels=self.get_panels())
 
     def get_blueprint(self, blueprint_name):
         return Blueprint(
@@ -684,6 +608,68 @@ class Admin(object):
         self.configure_routes()
         self.register_blueprint()
 
+    def get_model_field(self, model, field):
+        try:
+            attr = getattr(model, field)
+        except AttributeError:
+            model_admin = self[type(model)]
+            try:
+                attr = getattr(model_admin, field)
+            except AttributeError:
+                raise AttributeError('Could not find attribute or method '
+                                     'named "%s".' % field)
+            else:
+                return attr(model)
+        else:
+            if callable(attr):
+                attr = attr()
+            return attr
+
+    def get_form_field(self, form, field_name):
+        return getattr(form, field_name)
+
+    def fix_underscores(self, s):
+        return s.replace('_', ' ').title()
+
+    def update_querystring(self, querystring, key, val):
+        if not querystring:
+            return '%s=%s' % (key, val)
+        else:
+            querystring = re.sub(r'%s(?:[^&]+)?&?' % key, '', querystring.decode('utf8')).rstrip('&')
+            return ('%s&%s=%s' % (querystring, key, val)).lstrip('&')
+
+    def get_verbose_name(self, model, column_name):
+        try:
+            field = model._meta.fields[column_name]
+        except KeyError:
+            return self.fix_underscores(column_name)
+        else:
+            return field.verbose_name or self.fix_underscores(field.name)
+
+    def get_admin_url(self, obj):
+        model_admin = self.get_admin_for(type(obj))
+        if model_admin:
+            return url_for(model_admin.get_url_name('edit'), pk=obj._pk)
+
+    def get_logout_url(self):
+        return url_for('%s.logout' % self.auth.blueprint.name)
+
+    def get_model_name(self, model_class):
+        model_admin = self.get_admin_for(model_class)
+        if model_admin:
+            return model_admin.get_display_name()
+        return model_class.__name__
+
+    def apply_prefix(self, field_name, prefix_accum, field_prefix, rel_prefix='fr_', rel_sep='-'):
+        accum = []
+        for prefix in prefix_accum:
+            accum.append('%s%s' % (rel_prefix, prefix))
+        accum.append('%s%s' % (field_prefix, field_name))
+        return rel_sep.join(accum)
+
+    def prepare_template_environment(self):
+        self.app.jinja_env.filters['apply_prefix'] = self.apply_prefix
+
 
 class Export(object):
     def __init__(self, query, related, fields):
