@@ -1,9 +1,6 @@
 import functools
+import json
 import operator
-try:
-    import simplejson as json
-except ImportError:
-    import json
 
 from flask import Blueprint
 from flask import Response
@@ -20,6 +17,7 @@ from flask_peewee.filters import make_field_tree
 from flask_peewee.serializer import Deserializer
 from flask_peewee.serializer import Serializer
 from flask_peewee.utils import PaginatedQuery
+from flask_peewee.utils import convert_boolean
 from flask_peewee.utils import get_object_or_404
 from flask_peewee.utils import slugify
 from flask_peewee._compat import reduce
@@ -195,6 +193,9 @@ class RestResource(object):
 
         # clean and normalize the request parameters
         for key in request.args:
+            if key in ('ordering', 'page', 'limit'):
+                continue
+
             orig_key = key
             if key.startswith('-'):
                 negated = True
@@ -212,6 +213,9 @@ class RestResource(object):
             raw_filters.setdefault(expr, [])
             raw_filters[expr].append((op, request.args.getlist(orig_key), negated))
 
+        if not raw_filters:
+            return query
+
         # do a breadth first search across the field tree created by filter_fields,
         # searching for matching keys in the request parameters -- when found,
         # filter the query accordingly
@@ -220,10 +224,11 @@ class RestResource(object):
             node, prefix = queue.pop(0)
             for field in node.fields:
                 filter_expr = '%s%s' % (prefix, field.name)
+
                 if filter_expr in raw_filters:
-                    for op, arg_list, negated in raw_filters[filter_expr]:
+                    for op, arg_list, negated in raw_filters.pop(filter_expr):
                         clean_args = self.clean_arg_list(arg_list)
-                        query = self.apply_filter(query, filter_expr, op, clean_args, negated)
+                        query = self.apply_filter(query, field, filter_expr, op, clean_args, negated)
 
             for child_prefix, child_node in node.children.items():
                 queue.append((child_node, prefix + child_prefix + '__'))
@@ -233,9 +238,12 @@ class RestResource(object):
     def clean_arg_list(self, arg_list):
         return [self.value_transforms.get(arg, arg) for arg in arg_list]
 
-    def apply_filter(self, query, expr, op, arg_list, negated):
+    def apply_filter(self, query, field, expr, op, arg_list, negated):
         query_expr = '%s__%s' % (expr, op)
         constructor = lambda kwargs: negated and ~DQ(**kwargs) or DQ(**kwargs)
+        if isinstance(field, BooleanField):
+            arg_list = [convert_boolean(arg) for arg in arg_list]
+
         if op == 'in':
             # in gives us a string format list '1,2,3,4'
             # we have to turn it into a list before passing to
@@ -375,6 +383,7 @@ class RestResource(object):
         return {
             'model': self.get_api_name(),
             'page': current_page,
+            'page_count': paginated_query.get_pages(),
             'previous': previous,
             'next': next,
         }
