@@ -10,15 +10,21 @@ from flask_peewee.utils import get_model_from_dictionary
 class Serializer(object):
     date_format = '%Y-%m-%d'
     time_format = '%H:%M:%S'
-    datetime_format = ' '.join([date_format, time_format])
+    datetime_format = 'T'.join([date_format, time_format])
+    use_iso8601 = True
 
     def convert_value(self, value):
         if isinstance(value, datetime.datetime):
-            return value.strftime(self.datetime_format)
+            if self.use_iso8601:
+                return value.isoformat()
+            else:
+                return value.strftime(self.datetime_format)
         elif isinstance(value, datetime.date):
             return value.strftime(self.date_format)
         elif isinstance(value, datetime.time):
             return value.strftime(self.time_format)
+        elif isinstance(value, datetime.timedelta):
+            return value.total_seconds()
         elif isinstance(value, Model):
             return value._pk
         elif isinstance(value, uuid.UUID):
@@ -31,7 +37,7 @@ class Serializer(object):
             if isinstance(value, dict):
                 self.clean_data(value)
             elif isinstance(value, (list, tuple)):
-                data[key] = map(self.clean_data, value)
+                data[key] = list(map(self.clean_data, value))
             else:
                 data[key] = self.convert_value(value)
         return data
