@@ -1,12 +1,6 @@
-from __future__ import with_statement
-
-try:
-    import simplejson as json
-except ImportError:
-    import json
-
 import base64
 import datetime
+import json
 import unittest
 
 from flask import g
@@ -49,7 +43,7 @@ class RestApiTestCase(FlaskPeeweeTestCase):
         return {'Authorization': 'Basic %s' % base64.b64encode(data.encode('utf8')).decode('utf8')}
 
     def conv_date(self, dt):
-        return dt.strftime('%Y-%m-%d %H:%M:%S')
+        return dt.isoformat()
 
     def assertAPIResponse(self, resp_json, body):
         self.assertEqual(body, resp_json['objects'])
@@ -514,6 +508,7 @@ class RestApiBasicTestCase(RestApiTestCase):
         self.assertEqual(resp_json['meta']['model'], 'note')
         self.assertEqual(resp_json['meta']['previous'], '')
         self.assertEqual(resp_json['meta']['page'], 1)
+        self.assertEqual(resp_json['meta']['page_count'], 2)
         self.assertTrue('page=2' in resp_json['meta']['next'])
 
         # verify response objects are paginated properly
@@ -526,6 +521,7 @@ class RestApiBasicTestCase(RestApiTestCase):
         self.assertEqual(resp_json['meta']['model'], 'note')
         self.assertEqual(resp_json['meta']['previous'], '')
         self.assertEqual(resp_json['meta']['page'], 1)
+        self.assertEqual(resp_json['meta']['page_count'], 3)
         self.assertTrue('page=2' in resp_json['meta']['next'])
 
         # verify response objects are paginated properly
@@ -537,6 +533,7 @@ class RestApiBasicTestCase(RestApiTestCase):
 
         self.assertEqual(resp_json['meta']['model'], 'note')
         self.assertEqual(resp_json['meta']['page'], 2)
+        self.assertEqual(resp_json['meta']['page_count'], 3)
         self.assertTrue('page=1' in resp_json['meta']['previous'])
         self.assertTrue('page=3' in resp_json['meta']['next'])
 
@@ -567,6 +564,7 @@ class RestApiBasicTestCase(RestApiTestCase):
             'previous': '',
             'next': '',
             'page': 1,
+            'page_count': 1,
         })
         self.assertAPINotes(resp_json, self.normal.note_set.order_by(Note.id))
 
@@ -579,6 +577,7 @@ class RestApiBasicTestCase(RestApiTestCase):
             'previous': '',
             'next': '',
             'page': 1,
+            'page_count': 1,
         })
         self.assertAPINotes(resp_json, self.admin.note_set.order_by(Note.id))
 
@@ -599,6 +598,7 @@ class RestApiBasicTestCase(RestApiTestCase):
             'previous': '',
             'next': '',
             'page': 1,
+            'page_count': 1,
         })
         self.assertAPINotes(resp_json, Note.filter(user__in=[self.admin, self.inactive]).order_by(Note.id))
 
@@ -619,6 +619,14 @@ class RestApiBasicTestCase(RestApiTestCase):
         resp_json = self.response_json(resp)
         self.assertAPIUsers(resp_json, User.filter(username__in=['admin', 'normal']).order_by(User.id))
 
+        for falsey in ('0', '', 'false', 'f'):
+            resp = self.app.get('/api/user/?admin=%s' % falsey)
+            resp_json = self.response_json(resp)
+            self.assertAPIUsers(resp_json, User.filter(username='normal').order_by(User.id))
+
+        resp = self.app.get('/api/user/?admin=true')
+        resp_json = self.response_json(resp)
+        self.assertAPIUsers(resp_json, User.filter(username='admin').order_by(User.id))
 
     def test_filter_with_pagination(self):
         users, notes = self.get_users_and_notes()
@@ -656,6 +664,27 @@ class RestApiBasicTestCase(RestApiTestCase):
         self.assertEqual(resp_json['meta']['previous'], '')
         self.assertAPINotes(resp_json, notes[:4])
 
+    def test_filter_null(self):
+        e1 = EModel.create(e_field='e1')
+        f1 = FModel.create(e=e1, f_field='f1')
+        f2 = FModel.create(f_field='f2')
+
+        resp = self.app.get('/api/fmodel/?ordering=id')
+        resp_json = self.response_json(resp)
+        self.assertEqual(resp_json['objects'], [
+            {'id': f1.id, 'e': {'id': e1.id, 'e_field': 'e1'}, 'f_field': 'f1'},
+            {'id': f2.id, 'e': None, 'f_field': 'f2'}])
+
+        resp = self.app.get('/api/fmodel/?e__is=None')
+        resp_json = self.response_json(resp)
+        self.assertEqual(resp_json['objects'], [
+            {'id': f2.id, 'e': None, 'f_field': 'f2'}])
+
+        resp = self.app.get('/api/fmodel/?-e__is=None')
+        resp_json = self.response_json(resp)
+        self.assertEqual(resp_json['objects'], [
+            {'id': f1.id, 'e': {'id': e1.id, 'e_field': 'e1'}, 'f_field': 'f1'}])
+
 
 class RestApiUserAuthTestCase(RestApiTestCase):
     def setUp(self):
@@ -675,7 +704,12 @@ class RestApiUserAuthTestCase(RestApiTestCase):
         resp_json = self.response_json(resp)
 
         self.assertAPIResponse(resp_json, [])
-        self.assertAPIMeta(resp_json, {'model': 'note', 'next': '', 'page': 1, 'previous': ''})
+        self.assertAPIMeta(resp_json, {
+            'model': 'note',
+            'next': '',
+            'page': 1,
+            'page_count': 0,
+            'previous': ''})
 
         self.create_notes()
 
@@ -727,6 +761,20 @@ class RestApiUserAuthTestCase(RestApiTestCase):
         resp_json = self.response_json(resp)
         self.assertAPINote(resp_json, new_note)
 
+        note_data = {'message': 'test2', 'user': self.inactive.id,
+                     'created_date': '2026-01-02T03:04:05'}
+        resp = self.app.post('/api/note/', data=json.dumps(note_data),
+                             headers=self.auth_headers('normal', 'normal'))
+        new_note = Note.get(message='test2')
+        self.assertEqual(new_note.user, self.inactive)
+        self.assertEqual(new_note.created_date,
+                         datetime.datetime(2026, 1, 2, 3, 4, 5))
+
+        resp_json = self.response_json(resp)
+        self.assertEqual(resp_json, {
+            'message': 'test2', 'user': self.inactive.id, 'id': new_note.id,
+            'created_date': '2026-01-02T03:04:05'})
+
     def test_auth_edit(self):
         self.create_notes()
 
@@ -815,7 +863,12 @@ class RestApiOwnerAuthTestCase(RestApiTestCase):
         resp_json = self.response_json(resp)
 
         self.assertAPIResponse(resp_json, [])
-        self.assertAPIMeta(resp_json, {'model': 'message', 'next': '', 'page': 1, 'previous': ''})
+        self.assertAPIMeta(resp_json, {
+            'model': 'message',
+            'next': '',
+            'page': 1,
+            'page_count': 0,
+            'previous': ''})
 
         self.create_messages()
 
@@ -954,7 +1007,12 @@ class RestApiAdminAuthTestCase(RestApiTestCase):
         resp_json = self.response_json(resp)
 
         self.assertAPIResponse(resp_json, [])
-        self.assertAPIMeta(resp_json, {'model': 'user', 'next': '', 'page': 1, 'previous': ''})
+        self.assertAPIMeta(resp_json, {
+            'model': 'user',
+            'next': '',
+            'page': 1,
+            'page_count': 0,
+            'previous': ''})
 
         self.create_users()
 
@@ -1133,7 +1191,12 @@ class RestApiKeyAuthTestCase(RestApiTestCase):
                 self.tm1,
                 self.tm2,
             ])
-            self.assertAPIMeta(resp_json, {'model': 'testmodel', 'next': '', 'page': 1, 'previous': ''})
+            self.assertAPIMeta(resp_json, {
+                'model': 'testmodel',
+                'next': '',
+                'page': 1,
+                'page_count': 1,
+                'previous': ''})
 
     def test_auth_headers(self):
         with self.flask_app.test_client() as c:
