@@ -1,3 +1,4 @@
+import datetime
 import math
 import random
 import re
@@ -7,6 +8,8 @@ from hashlib import sha1
 from flask import abort
 from flask import render_template
 from flask import request
+from peewee import BooleanField
+from peewee import DateTimeField
 from peewee import DoesNotExist
 from peewee import ForeignKeyField
 from peewee import Model
@@ -48,10 +51,15 @@ class PaginatedQuery(object):
             return int(curr_page)
         return 1
 
+    def get_count(self):
+        if not hasattr(self, '_get_count'):
+            self._get_count = self.query.count()
+        return self._get_count
+
     def get_pages(self):
         if not hasattr(self, '_get_pages'):
             self._get_pages = int(math.ceil(
-                float(self.query.count()) / self.paginate_by))
+                float(self.get_count()) / self.paginate_by))
         return self._get_pages
 
     def get_list(self):
@@ -64,7 +72,7 @@ def get_next():
     return '%s?%s' % (request.path, request.query_string)
 
 def slugify(s):
-    return re.sub('[^a-z0-9_\-]+', '-', s.lower())
+    return re.sub(r'[^a-z0-9_\-]+', '-', s.lower())
 
 def load_class(s):
     path, klass = s.rsplit('.', 1)
@@ -103,7 +111,7 @@ def get_model_from_dictionary(model, field_dict):
     models = [model_instance]
     for field_name, value in field_dict.items():
         field_obj = model._meta.fields[field_name]
-        if isinstance(value, dict):
+        if isinstance(value, dict) and isinstance(field_obj, ForeignKeyField):
             rel_obj = field_obj.rel_model
             if check_fks:
                 try:
@@ -116,9 +124,28 @@ def get_model_from_dictionary(model, field_dict):
             models.extend(rel_models)
             setattr(model_instance, field_name, rel_inst)
         else:
+            if isinstance(field_obj, BooleanField):
+                if isinstance(value, str) and value.lower() in ('0', 'f', 'false', ''):
+                    value = False
+            elif isinstance(field_obj, DateTimeField):
+                value = deserialize_datetime(field_obj, value)
+
             setattr(model_instance, field_name, field_obj.python_value(value))
     return model_instance, models
 
+def deserialize_datetime(field_obj, value):
+    formats = ('%Y-%m-%dT%H:%M:%S%z',
+               '%Y-%m-%dT%H:%M:%S.%f',
+               '%Y-%m-%dT%H:%M:%S',
+               '%Y-%m-%dT',
+               '%Y-%m-%d')
+    for fmt in formats:
+        try:
+            return datetime.datetime.strptime(value, fmt)
+        except Exception:
+            continue
+    return value
+
 def path_to_models(model, path):
     accum = []
     if '__' in path:
@@ -135,6 +162,12 @@ def path_to_models(model, path):
     return accum
 
 
+def convert_boolean(s):
+    if isinstance(s, str) and s.lower() in ('', '0', 'false', 'f'):
+        return False
+    return bool(s)
+
+
 # borrowing these methods, slightly modified, from django.contrib.auth
 def get_hexdigest(salt, raw_password):
     data = salt + raw_password
